==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/ServiceDiscovery/GetNamespace.pm <==

package Paws::ServiceDiscovery::GetNamespace;
  use Moose;
  has Id => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetNamespace');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ServiceDiscovery::GetNamespaceResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceDiscovery::GetNamespace - Arguments for method GetNamespace on L<Paws::ServiceDiscovery>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetNamespace on the
L<Amazon Route 53 Auto Naming|Paws::ServiceDiscovery> service. Use the attributes of this class
as arguments to method GetNamespace.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetNamespace.

=head1 SYNOPSIS

    my $servicediscovery = Paws->service('ServiceDiscovery');
    my $GetNamespaceResponse = $servicediscovery->GetNamespace(
      Id => 'MyResourceId',

    );

    # Results:
    my $Namespace = $GetNamespaceResponse->Namespace;

    # Returns a L<Paws::ServiceDiscovery::GetNamespaceResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/servicediscovery/GetNamespace>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Id => Str

The ID of the namespace that you want to get information about.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetNamespace in L<Paws::ServiceDiscovery>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/ServiceDiscovery/GetNamespace.pm <==

package Paws::ServiceDiscovery::GetNamespace;
  use Moose;
  has Id => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetNamespace');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ServiceDiscovery::GetNamespaceResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceDiscovery::GetNamespace - Arguments for method GetNamespace on L<Paws::ServiceDiscovery>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetNamespace on the
L<AWS Cloud Map|Paws::ServiceDiscovery> service. Use the attributes of this class
as arguments to method GetNamespace.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetNamespace.

=head1 SYNOPSIS

    my $servicediscovery = Paws->service('ServiceDiscovery');
    my $GetNamespaceResponse = $servicediscovery->GetNamespace(
      Id => 'MyResourceId',

    );

    # Results:
    my $Namespace = $GetNamespaceResponse->Namespace;

    # Returns a L<Paws::ServiceDiscovery::GetNamespaceResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/servicediscovery/GetNamespace>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Id => Str

The ID of the namespace that you want to get information about.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetNamespace in L<Paws::ServiceDiscovery>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
